import Modal from '@/components/HncyModal';
import Tabs from '@/components/Tabs';
import ToggleView from '@/components/ToggleView';
import BaseCard from '@/pages/Common/components/BaseCard';
import EventPicList from '@/pages/Common/components/EventPicList';
import ListView from '@/pages/Common/components/ListView';
import ProcessCard from '@/pages/Common/components/ProcessCard';
import EventDetail from '@/pages/Common/Event/EventDetail';
import services from '@/services';
import { Flex, Space } from 'antd';
import { useEffect, useRef, useState } from 'react';
import styles from './index.less';
import LineCharts from './LineCharts';

const UrbanOperation = () => {
  // 事件详情弹窗
  const [detailModalOpt, setDetailModalOpt] = useState<{
    open: boolean;
    title: string;
    eventId: string;
  }>({
    open: false,
    title: '',
    eventId: '',
  });

  // 视图
  const [viewType, setViewType] = useState<'list' | 'pic'>('pic'); //展示

  const fetchParams = useRef({
    page: 1,
    count: 10,
    caseStatus: "",
    eventType: '5',
  });

   // tabs内容
   const defalutTabItems = [
    {
      key: '',
      label: '全部',
    },
    {
      key: '40,50,60',
      label: '处置中',
    },
    {
      key: '90',
      label: '已办结',
    },
  ];

  //事件列表
  const [listData, setListData] = useState<any>({
    items: [],
    loading: true,
    total: 0,
    page: 1,
    hasNext: false,
  });

  const [eventStatistics, setEventStatistics] = useState<any>({});
  const [categoryStatistics, setCategoryStatistics] = useState([]);
  const [areaStatistics, setAreaStatistics] = useState([]);

  // 获取左侧顶部事件相关统计
  const getCityStatistics = () => {
    const params = {
      eventType: '5',
    };
    services.CityProblemApi.getContentStatisticsApi(params).then((res) => {
      if (res.code === 200) {
        setEventStatistics(res.data);
      }
    });
  };

  // 高发类别统计
  const getCategoryAnalysis = (category = 'mainClass') => {
    const params = {
      category: category,
      top: 3,
      eventType: '5',
    };
    services.CityProblemApi.getCategoryTopAnalysisApi(params).then((res) => {
      if (res.code === 200) {
        setCategoryStatistics(res.data);
      }
    });
  };

  const onChangeCategory = (value: string) => {
    getCategoryAnalysis(value);
  };

  // 高发类别统计
  const getAreaAnalysis = () => {
    const params = {
      region: 'district',
      top: 3,
      eventType: '5',
    };
    services.CityProblemApi.getAreaDistribAnalysisApi(params).then((res) => {
      if (res.code === 200) {
        setAreaStatistics(res.data);
      }
    });
  };

  // 事件列表
  const getEventsList = () => {
    services.CityProblemApi.getZzEventListApi(fetchParams.current).then((res) => {
      if (res.code === 200) {
        let result = {
          ...res.data,
          items:
            fetchParams.current.page === 1 ? res.data.items : [...listData.items, ...res.data.items],
        };
        setListData(result);
      }
    });
  };

  const changeListTab = (value: string) => {
    fetchParams.current.caseStatus = value
    fetchParams.current.page = 1
    setListData({
      items: [],
      loading: true,
      total: 0,
      page: 1,
      hasNext: false,
    })
    getEventsList();
  };

  useEffect(() => {
    getCityStatistics();
    getCategoryAnalysis();
    getAreaAnalysis();
    getEventsList();
  }, []);

  return (
    <Flex gap={30} className={styles.wrap}>
      <Space direction="vertical" size={15} className={styles.left}>
        <BaseCard
          style={{
            paddingTop: 15,
          }}
        >
          <Flex justify="space-between" className={styles.top}>
            <Space direction="vertical">
              <span>
                <span className={styles.num}>
                  {eventStatistics.total}
                </span>
                <span>件</span>
              </span>
              <span>总量</span>
            </Space>
            <Space direction="vertical">
              <span>
                <span className={styles.num}>
                  {eventStatistics.caseClosedNum}
                </span>
                <span>件</span>
              </span>
              <span>已办结</span>
            </Space>
            <Space direction="vertical">
              <span>
                <span className={styles.num}>{eventStatistics.ratio}</span>
                <span>%</span>
              </span>
              <span>办结率</span>
            </Space>
          </Flex>
        </BaseCard>

        <BaseCard
          title="趋势（近30天）"
          style={{
            paddingTop: 20,
          }}
        >
          <div style={{ padding: '15px', width: '100%', height: '100%' }}>
            <LineCharts data={eventStatistics.lately} />
          </div>
        </BaseCard>

        <ProcessCard
          title="高发类别"
          extra={
            <Tabs
              style={{
                background: 'transparent',
                height: '30px',
              }}
              itemStyle={{
                borderRadius: '25px',
                background: 'rgba(7, 50, 93, 0.8)',
                fontSize: '16px',
                marginLeft: 8,
              }}
              onChange={onChangeCategory}
              itemkey={'key'}
              items={[
                {
                  key: 'mainClass',
                  label: '大类',
                },
                {
                  key: 'subClass',
                  label: '小类',
                },
                {
                  key: 'subdivisionClass',
                  label: '细类',
                },
              ]}
            />
          }
          data={categoryStatistics}
          strokeColor={{
            '0%': '#38F2E3',
            '100%': '#3DC3FF',
          }}
        />

        <ProcessCard
          title="高发区域"
          data={areaStatistics}
          strokeColor={{
            '0%': '#FFCCCC',
            '100%': '#EEFFEB',
          }}
        />
      </Space>
      <div className={styles.right}>
        <Flex justify="flex-end" style={{ marginBottom: 20 }}>
          <Space size={20}>
            <Tabs
              onChange={changeListTab}
              itemkey={'key'}
              items={defalutTabItems}
            />
            <ToggleView type={viewType} setType={(type) => setViewType(type)} />
          </Space>
        </Flex>
        {viewType === 'list' ? (
          <ListView
            listData={listData}
            listHeight={540}
            setParams={(data) => {
              fetchParams.current.page = data.pageNum;
              fetchParams.current.count = data.pageSize;
              getEventsList()
            }}
            handleDetail={(details) => {
              setDetailModalOpt({
                open: true,
                title: '事件详情',
                eventId: details.eventId,
              });
            }}
          />
        ) : (
          <EventPicList
            listData={listData}
            listHeight={640}
            setParams={(page) => {
              fetchParams.current.page = page;
              getEventsList()
            }}
            handleDetail={(details) => {
              setDetailModalOpt({
                open: true,
                title: '事件详情',
                eventId: details.eventId,
              });
            }}
          />
        )}
      </div>
      <Modal
        open={detailModalOpt?.open}
        title={detailModalOpt?.title}
        onCancel={() =>
          setDetailModalOpt({ open: false, title: '', eventId: '' })
        }
        width={'fit-content'}
        height={950}
      >
        <EventDetail eventId={detailModalOpt?.eventId} />
      </Modal>
    </Flex>
  );
};

export default UrbanOperation;
